@@ -1,2 +1,3 @@
 from pm4py.statistics import traces, performance_spectrum, attributes, variants, start_activities, end_activities, util, \
-    sojourn_time
+    sojourn_time, concurrent_activities
+
